@@ -1,14 +1,14 @@
-# Copyrights 2006-2019 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2006-2024 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
+# Pod stripped from pm file by OODoc 2.03.
 # This code is part of distribution XML-Compile.  Meta-POD processed with
 # OODoc into POD and HTML manual-pages.  See README.md
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
-package XML::Compile::Translate;
-use vars '$VERSION';
-$VERSION = '1.62';
+package XML::Compile::Translate;{
+our $VERSION = '1.64';
+}
 
 
 use warnings;
@@ -652,12 +652,10 @@ sub element($;$)
     if(my $isa    = $node->getAttribute('type'))
     {   # explicitly names type
         $nr_childs==0
-            or error __x"no childs expected with attribute `type' at {where}"
-                 , where => $where, _class => 'schema';
+            or error __x"no childs expected with attribute `type' at {where}", where => $where, _class => 'schema';
 
         $comptype = $self->rel2abs($where, $node, $isa);
-        $comps    = $self->blocked($where, anyType => $comptype)
-                 || $self->typeByName($where, $tree, $comptype);
+        $comps    = $self->blocked($where, anyType => $comptype) || $self->typeByName($where, $tree, $comptype);
     }
     elsif($nr_childs==0)
     {   # default type for substGroups is type of base-class
@@ -672,8 +670,7 @@ sub element($;$)
                 or next;
 
             $comptype  = $self->rel2abs($where, $base_node, $isa);
-            $comps     = $self->blocked($where, complexType => $comptype)
-                      || $self->typeByName($where, $tree, $comptype);
+            $comps     = $self->blocked($where, complexType => $comptype) || $self->typeByName($where, $tree, $comptype);
             last;
         }
         unless($comptype)
@@ -691,13 +688,17 @@ sub element($;$)
         my $local = $child->localname;
         my $nest  = $tree->descend($child);
 
+        # Sometimes extension or restriction with base attribute required for hooks
+        my $ext   = $nest->firstChild;
+        my $base  = $ext  ? $ext->getAttribute('base') : undef;
+        my $basex = $base ? $self->rel2abs($where, $ext, $base) : undef;
+
         ($comps, $comptype)
           = $local eq 'simpleType'
-          ? ($self->simpleType($nest, 0), 'unnamed simple')
+          ? ($self->simpleType($nest, 0), $basex // 'unnamed simple')
           : $local eq 'complexType'
-          ? ($self->complexType($nest), 'unnamed complex')
-          : error __x"illegal element child `{name}' at {where}"
-                , name => $local, where => $where, _class => 'schema';
+          ? ($self->complexType($nest), $basex // 'unnamed complex')
+          : error __x"illegal element child `{name}' at {where}", name => $local, where => $where, _class => 'schema';
     }
 
     my ($st, $elems, $attrs, $attrs_any)
@@ -723,8 +724,7 @@ sub element($;$)
     my $fixed    = $node->getAttributeNode('fixed');
 
     $default && $fixed
-        and error __x"element can not have default and fixed at {where}"
-              , where => $tree->path, _class => 'schema';
+        and error __x"element can not have default and fixed at {where}", where => $tree->path, _class => 'schema';
 
     my $value
       = $default  ? $default->textContent
@@ -744,10 +744,9 @@ sub element($;$)
         if $self->{permit_href} && $self->actsAs('READER');
 
     # Implement hooks
-    my ($before, $replace, $after)
-      = $self->findHooks($where, $comptype, $node);
+    my ($before, $replace, $after) = $self->findHooks($where, $comptype, $node);
 
-    $do = $self->makeHook($where,$do,$tag,$before,$replace,$after,$comptype)
+    $do = $self->makeHook($where, $do, $tag, $before, $replace, $after, $comptype)
         if $before || $replace || $after;
 
     $do = $self->xsiType($tree, $node, $name, $comptype, $do)
@@ -878,10 +877,11 @@ sub particleGroup($)
     # apparently, a group can not refer to a group... well..
 
     my $node  = $tree->node;
-    my $where = $tree->path . '#group';
     my $ref   = $node->getAttribute('ref')
         or error __x"group without ref at {where}"
-             , where => $where, _class => 'schema';
+             , where => $tree->path, _class => 'schema';
+
+    my $where = $tree->path . '#' . $ref;
 
     my $typename = $self->rel2abs($where, $node, $ref);
     if(my $blocked = $self->blocked($where, ref => $typename))
@@ -889,23 +889,20 @@ sub particleGroup($)
     }
 
     my $dest  = $self->namespaces->find(group => $typename)
-        or error __x"cannot find group `{name}' at {where}"
-             , name => $typename, where => $where, _class => 'schema';
+        or error __x"cannot find group `{name}' at {where}", name => $typename, where => $where, _class => 'schema';
 
     my $group = $tree->descend($dest->{node}, $self->prefixed($typename, 1));
     return () if $group->nrChildren==0;
 
     $group->nrChildren==1
-        or error __x"only one particle block expected in group `{name}' at {where}"
-               , name => $typename, where => $where, _class => 'schema';
+        or error __x"only one particle block expected in group `{name}' at {where}", name => $typename, where => $where, _class => 'schema';
 
     my $local = $group->currentLocal;
     $local    =~ m/^(?:all|choice|sequence)$/
-        or error __x"illegal group member `{name}' at {where}"
-             , name => $local, where => $where, _class => 'schema';
+        or error __x"illegal group member `{name}' at {where}", name => $local, where => $where, _class => 'schema';
 
     my ($blocklabel, $code) = $self->particleBlock($group->descend);
-    ($typename, $code);
+    $code ? ($typename, $code) : ();
 }
 
 sub particleBlock($)
@@ -1021,12 +1018,14 @@ sub keyRewrite($;$)
 }
 
 sub prefixed($;$)
-{   my ($self, $qname, $hide) = @_;
+{   my ($self, $qname, $hide_use) = @_;
+    # hide_use = do not cause inclusion in output prefix table
+
     my ($ns, $local) = unpack_type $qname;
     defined $ns or return $qname;
 
     my $pn = $self->{prefixes}{$ns} or return;
-    $pn->{used}++ unless $hide ;
+    $pn->{used}++ unless $hide_use;
     length $pn->{prefix} ? "$pn->{prefix}:$local" : $local;
 }
 
@@ -1093,10 +1092,11 @@ sub attribute($)
     }
 
     # no default prefixes for attributes
-    error __x"attribute namespace {ns} cannot be the default namespace"
-      , ns => $ns
-        if $qual && $ns && $self->prefixForNamespace($ns) eq '';
-        
+#warn "#", $self->prefixForNamespace($ns), "#";
+#    error __x"attribute namespace {ns} cannot be the default namespace"
+#      , ns => $ns
+#        if $qual && $ns && $self->prefixForNamespace($ns) eq '';
+
     my ($type, $typeattr);
     if($tree->nrChildren==1)
     {   $tree->currentLocal eq 'simpleType'
@@ -1366,8 +1366,7 @@ sub simpleContent($)
     # content: annotation?, (restriction | extension)
 
     $tree->nrChildren==1
-        or error __x"need one simpleContent child at {where}"
-             , where => $tree->path, _class => 'schema';
+        or error __x"need one simpleContent child at {where}", where => $tree->path, _class => 'schema';
 
     my $name  = $tree->currentLocal;
     return $self->simpleContentExtension($tree->descend)
@@ -1393,20 +1392,17 @@ sub simpleContentExtension($)
     my $where    = $tree->path . '#sext';
 
     my $base     = $node->getAttribute('base');
-    my $typename = defined $base ? $self->rel2abs($where, $node, $base)
-     : $self->anyType($node);
+    my $typename = defined $base ? $self->rel2abs($where, $node, $base) : $self->anyType($node);
 
     my $basetype = $self->blocked($where, simpleType => $typename)
                 || $self->typeByName($where, $tree, $typename);
     defined $basetype->{st}
-        or error __x"base of simpleContent not simple at {where}"
-             , where => $where, _class => 'schema';
+        or error __x"base of simpleContent not simple at {where}", where => $where, _class => 'schema';
  
     $self->extendAttrs($basetype, {$self->attributeList($tree)});
 
     $tree->currentChild
-        and error __x"elements left at tail at {where}"
-              , where => $tree->path, _class => 'schema';
+        and error __x"elements left at tail at {where}", where => $tree->path, _class => 'schema';
 
     $basetype;
 }
